CleanNaFromFactor.CausataData: Given a factor in a CausataData object, this replaces missing values.
Description
Missing values are replaced with the string "BLANK", or any other string supplied as an input.
Usage
## S3 method for class 'CausataData':
CleanNaFromFactor(x, variableName=NULL, replacement="BLANK", ...)
Arguments
x
An object from CausataData.
variableName
If a name is supplied then the variable matching the name will have CleanNaFromFactor applied.
If no name is provided then CleanNaFromFactor is applied to every factor in causataData.
replacement
Levels with missing values will be replaced with this string.
...
Unused arguments for other methods.
Value
Returns a CausataData object with the missing value replacements recorded.