Learn R Programming

Causata (version 4.1-0)

RToCausataNames: Converts R-friendly causata column names to the corresponding Causata system name

Description

Converts R-friendly causata column names to the corresponding Causata system name

Usage

RToCausataNames(name.vector)

Arguments

name.vector
A character vector of column names.

Value

  • An character vector of mapped variable names.

Details

Causata variables follow two naming conventions. The first is found in data exported from within Causata using the "R Formated CSV" option:

variable.name_Time.Domain_id where id is a number, e.g. variable.name_Time.Domain_123

The second convention is found in data exported from the SQL interface:

variable.name__Time.Domain

Example conversions:

variable.name__Time.Domain becomes variable-name$Time Domain

variable.name_Time.Domain_123 is unchanged.

Variables that do not conform to these conventions will be mapped to "No Causata Name" and a warning will be triggered.

See Also

CausataData, CausataVariable, CausataToRNames.

Examples

Run this code
RToCausataNames(c("variable.name__Time.Domain", "variable.name_Time.Domain_123"))
RToCausataNames("bad-name-doesn't fit convention")

Run the code above in your browser using DataLab