Learn R Programming

Causata (version 4.1-0)

ReadCausataR: Parses an R file exported with Causata data.

Description

Parses an R file exported with Causata data. The information in the R file can be used to filter or select variables.

Usage

ReadCausataR(rFile, countRows=FALSE)

Arguments

rFile
The R file to process, including path.
countRows
If TRUE the rows in the CSV file will be counted. This step can reduce memory requirements.

Value

  • A list is returned with elements as follows:
  • fileRA filename of the R file, including the path.
  • fileDataA filename of the CSV data file, including the path.
  • colClassesThe classes of each column, e.g. numeric, factor, etc.
  • col.namesThe column names of each column.
  • nrowsThe number of rows in the CSV data. If countRows is FALSE then the value is set to -1.

Details

This function parses the R code exported with Causata data. File names, column names, and column classes are extracted.