Learn R Programming

Causata (version 4.1-0)

ToPmml: Generates a PMML representation of a model.

Description

Encodes a glmnet model in a string of PMML text for importing into Causata.

Usage

## S3 method for class 'GlmnetModelDefinition':
ToPmml(model.definition, variable.definition, verbose=FALSE, \dots)

Arguments

model.definition
An object from GlmnetModelDefinition.
variable.definition
An object from VariableDefinition.
verbose
If TRUE then translation information is printed to the console.
...
Extra unused arguments.

Value

  • Returns a string of PMML text.

Details

The PMML text string can be written to a file using the saveXML function from the XML package.

See Also

UploadModel, ModelDefinition, VariableDefinition, saveXML.